@@ -31,7 +31,7 @@ module type Fdkaac_t =
         type param =
             [ `Afterburner of bool
             | `Aot of aot
-            | `Bandwidth of bool
+            | `Bandwidth of int
             | `Bitrate of int
             | `Bitrate_mode of bitrate_mode
             | `Granule_length of int
